@@ -395,10 +395,11 @@ class gitricsGroup(GitlabGroup):
             ]
 
         # check for participants
-        elif item.participants:
+        if item.participants:
 
-            # because we can't determine level of participation list all with lowest score
-            result = [(d["id"], 0.1) for d in item.participants]
+            # because we can't determine level of participation
+            # initialize all with lowest score
+            result += [(d["id"], 0.1) for d in item.participants]
 
         return result
 
